==> ofscraper-2.7.6-py3-none-any.whl: ofscraper/prompts/prompt_strings.py <==
CHECKLISTINSTRUCTIONS=\
"""
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&

Instructions
============================================================
Enter one of the  'SELECT_KEYS' to confirm

MINUMUM CHOICE: 1
MAX_CHOICE:1
============================================================

KEYS
============================================================

   SELECT_KEYS
   ======================================================================
   END  |  HOME   | PAGEUP | PAGEDOWN | SPACE | ENTER
   ========================================================================

==============================================================
PRESS ENTER TO CONTINUE

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
"""





FUZZY_INSTRUCTION=\
"""
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&

Instructions
=========================================================================
Enter Confirm KEY to confirm selection

Parantheses indicates number of selected user


MINUMUM CHOICE: 1
MAX_CHOICE:ALL

=========================================================================

KEYS
=========================================================================
  CONFIRM_KEY          
  ============
  ENTER
  ================
 
 
 SELECT_KEYS
   ================================================
   END  |  HOME   | PAGEUP | PAGEDOWN | SPACE |
   ================================================


  TOGGLE_ALL_FALSE
   ========
   CTRL+D
   ========
  
  TOGGLE_ALL_TRUE
   ========
   CTRL+S
   ========

   TOGGLE_ALL
   ========
   CTRL+A
   ========
   

===================================================================
PRESS ENTER TO CONTINUE

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&"""



MODEL_FUZZY=\
"""
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&

Instructions
=========================================================================
Enter Confirm KEY to confirm selection

Parantheses indicates number of selected user


MINUMUM CHOICE: 1
MAX_CHOICE:ALL

=========================================================================

KEYS
=========================================================================
  CONFIRM_KEY          
  ============
  ENTER
  ================
 
 
 SELECT_KEYS
   ================================================
   END  |  HOME   | PAGEUP | PAGEDOWN | SPACE |
   ================================================

 



  TOGGLE_ALL_FALSE
   ========
   CTRL+D
   ========
  
  TOGGLE_ALL_TRUE
   ========
   CTRL+S
   ========


  TOGGLE_ALL
   ========
   CTRL+A
   ========


   CHANGE_FILTER/SORT
   ========
   ALT+X
   ========
===================================================================
PRESS ENTER TO CONTINUE

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&"""

SCRAPE_PAID=\
"""
This is meant really for scraping content for deleted models
This can greatly increase the time needed for a single scrape

It should not be needed to turn this on everytime, especially with  frequent scrapes

SHOW INSTRUCTIONS: [ALT+V]
"""


SINGLE_LINE=\
"""
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&


Instructions for submitting text
=========================================================================
HIT one of the 'SUBMIT_KEYs' to submit text
===========================================================================

KEYS
==========================================================================

   SUBMIT_KEYs
   ======================================================================
   END  |  HOME   | PAGEUP | PAGEDOWN | SPACE | ENTER
   ========================================================================

==============================================================================
PRESS ENTER TO CONTINUE

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&"""


KEY_BOARD=\
"""
SHOW INSTRUCTIONS: [ALT+V]
"""



MODEL_SELECT=\
"""
SHOW INSTRUCTIONS: [ALT+V]
CHANGE_SORT/CHANGE_FILTER: [ALT+X]
"""


MULTI_LINE=\
"""
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&

Instructions for editing
===========================================================================
HIT one of the 'SUBMIT' combinations when your auth syntax is corrected
============================================================================

KEYS
===========================================================================
   SUBMIT_KEYs
   ======================================================================
   END+ENTER  |  HOME+ENTER   | PAGEUP+ENTER | PAGEDOWN+ENTER | SPACE+ENTER
   ========================================================================

==============================================================================
PRESS ENTER TO CONTINUE

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
"""


AUTH_MULTI=\
"""
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&


Instructions for editing auth
=========================================================================
HIT one of the 'SUBMIT' combinations to confirm text
=========================================================================

KEYS
=========================================================================

   SUBMIT_KEYs
   ======================================================================
   END+ENTER  |  HOME+ENTER   | PAGEUP+ENTER | PAGEDOWN+ENTER | SPACE+ENTER
   ========================================================================

==============================================================================
PRESS ENTER TO CONTINUE

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
"""


CONFIG_MULTI=\
"""
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&

Instructions for editing config
=========================================================================
HIT one of the 'SUBMIT' combinations when your auth syntax is corrected
=========================================================================

KEYS
=========================================================================
   SUBMIT_KEYs
   ======================================================================
   END+ENTER  |  HOME+ENTER   | PAGEUP+ENTER | PAGEDOWN+ENTER | SPACE+ENTER
   ========================================================================

==============================================================================
PRESS ENTER TO CONTINUE

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
"""

==> ofscraper-3.6.8-py3-none-any.whl: ofscraper/prompts/prompt_strings.py <==
CHECKLISTINSTRUCTIONS = """
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&

Instructions
============================================================
Enter one of the  'SELECT KEYS' to confirm

MINUMUM CHOICE: 1
MAX CHOICE:1
============================================================

KEYS
============================================================

   SELECT KEYS
   ======================================================================
   END  |  HOME   | PAGEUP | PAGEDOWN | SPACE | ENTER | shift+right
   ========================================================================

   SPECIAL SELECT
   Will select and move cursor
   ================
   TAB | SHIFT+TAB 
   =================


==============================================================
PRESS ENTER TO RETURN

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
"""

FUZZY_INSTRUCTION = """
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&

Instructions
=========================================================================
Enter Confirm KEY to confirm selection

Parantheses indicates number of selected user


MINUMUM CHOICE: 1
MAX CHOICE:ALL

=========================================================================

KEYS
=========================================================================
  CONFIRM KEY          
  ============
  ENTER
  ================
 
 
   SELECT KEYS
   ================================================
   END  |  HOME | PAGEUP | PAGEDOWN | shift+right
   ================================================
   
   SPECIAL SELECT
   Will select and move cursor
   ================
   TAB | SHIFT+TAB 
   =================


  TOGGLE ALL FALSE
   ========
   CTRL+D
   ========
  
  TOGGLE ALL TRUE
   ========
   CTRL+S
   ========

   TOGGLE ALL
   ========
   CTRL+A
   ========
   

===================================================================
PRESS ENTER TO RETURN

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&"""

MODEL_FUZZY = """
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&

Instructions
=========================================================================
Enter Confirm KEY to confirm selection

Parantheses indicates number of selected user


MINUMUM CHOICE: 1
MAX CHOICE:ALL

=========================================================================

KEYS
=========================================================================
  CONFIRM KEY          
  ============
  ENTER
  ================
 
 
 SELECT KEYS
   ================================================
   END  |  HOME | PAGEUP | PAGEDOWN | shift+right
   ================================================

 SPECIAL SELECT
 Will select and move cursor
 ================
  TAB | SHIFT+TAB 
 =================


  TOGGLE ALL FALSE
   ========
   CTRL+D
   ========
  
  TOGGLE ALL TRUE
   ========
   CTRL+S
   ========


  TOGGLE ALL
   ========
   CTRL+A
   ========


   CHANGE FILTER/SORT
   ========
   ALT+X|CTRL+B
   ========
===================================================================
PRESS ENTER TO RETURN

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&"""

SCRAPE_PAID = """
This is meant really for scraping content for deleted models
This can greatly increase the time needed for a single scrape

It should not be needed to turn this on everytime, especially with  frequent scrapes

SHOW INSTRUCTIONS: [ALT+V] or [CTRL+V]
"""

SINGLE_LINE = """
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&


Instructions for submitting text
=========================================================================
HIT one of the 'SUBMIT KEYs' to submit text
===========================================================================

KEYS
==========================================================================

   SUBMIT KEYs
   ======================================================================
   END  |  HOME   | PAGEUP | PAGEDOWN | SPACE | ENTER | shift+right
   ========================================================================

==============================================================================
PRESS ENTER TO RETURN

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&"""

KEY_BOARD = """
SHOW INSTRUCTIONS: [ALT+V] or [CTRL+V]
"""

NUMBER = """
SHOW INSTRUCTIONS: [ALT+V] or [CTRL+V]
"""

MODEL_SELECT = """
SHOW INSTRUCTIONS: [ALT+V] or [CTRL+V]
CHANGE SORT/CHANGE FILTER: [ALT+X] or [CTRL+B]
MODEL DETAILS: [ALT+D]
"""

MULTI_LINE = """
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&

Instructions for editing
===========================================================================
HIT one of the 'SUBMIT' combinations when your auth syntax is corrected
============================================================================

KEYS
===========================================================================
   SUBMIT
   ==============================================================================
   END+ENTER  |  HOME+ENTER   | PAGEUP+ENTER | PAGEDOWN+ENTER | SPACE+ENTER | ESC
   ================================================================================

==============================================================================
PRESS ENTER TO RETURN

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
"""

AUTH_MULTI = """
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&


Instructions for editing auth
=========================================================================
HIT one of the 'SUBMIT' combinations to confirm text
=========================================================================

KEYS
=========================================================================

   SUBMIT KEYs
   =============================================================================
   END+ENTER  |  HOME+ENTER   | PAGEUP+ENTER | PAGEDOWN+ENTER | SPACE+ENTER| ESC
   =============================================================================

==============================================================================
PRESS ENTER TO RETURN

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
"""

CONFIG_MULTI = """
&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&

Instructions for editing config
=========================================================================
HIT one of the 'SUBMIT' combinations when your auth syntax is corrected
=========================================================================

KEYS
=========================================================================
   SUBMIT KEYs
   ================================================================================
   END+ENTER  |  HOME+ENTER   | PAGEUP+ENTER | PAGEDOWN+ENTER | SPACE+ENTER | ESC
   ===============================================================================

==============================================================================
PRESS ENTER TO RETURN

&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
"""
